@@ -4,7 +4,7 @@ from shipper.check_and_create_folder import check_and_create_folder
 from shipper.get_project_config import get_project_config
 
 
-def create_run_script(project_list, configs):
+def create_run_script(project_list, configs, tag):
     for project_name in project_list:
         project_config = get_project_config(project_name, configs)
         if project_config["type"] == "front-end":
@@ -53,14 +53,14 @@ def create_run_script(project_list, configs):
         with open(f'{docker_script_output_folder}/push.sh', "w+") as writer:
             writer.write('docker buildx create --name armbuilder\n')
             writer.write('docker buildx use armbuilder\n')
-            writer.write(f'docker buildx build --platform linux/amd64 -t jaytrairat/{project_name}:dev . --push\n')
+            writer.write(f'docker buildx build --platform linux/amd64 -t jaytrairat/{project_name}:{tag} . --push\n')
 
         with open(f'{docker_script_output_folder}/{project_name}.sh', "w+") as writer:
             writer.write('docker rmi $(docker images -f "dangling=true" -q)\n')
             writer.write(f"docker stop $(docker ps -a | grep {project_name} | awk '{{print $1}}')\n")
             writer.write(f"docker rm $(docker ps -a | grep {project_name} | awk '{{print $1}}')\n")
-            writer.write(f'docker pull jaytrairat/{project_name}:dev\n')
-            writer.write(f'docker run -dp {project_config["port"]} jaytrairat/{project_name}:dev\n')
+            writer.write(f'docker pull jaytrairat/{project_name}:{tag}\n')
+            writer.write(f'docker run -dp {project_config["port"]} jaytrairat/{project_name}:{tag}\n')
             writer.write('read -p "Press any key to continue"')
 
         with open(f'{docker_script_output_folder}/upload.sh', "w+") as writer:
